@@ -2,7 +2,7 @@
 package CPAN::Mirrored::By;
 use strict;
 
-sub new { 
+sub new {
     my($self,@arg) = @_;
     bless [@arg], $self;
 }
@@ -19,7 +19,7 @@ use File::Basename ();
 use File::Path ();
 use File::Spec ();
 use vars qw($VERSION $urllist);
-$VERSION = sprintf "%.6f", substr(q$Rev: 1372 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 1379 $,4)/1000000 + 5.4;
 
 =head1 NAME
 
@@ -265,9 +265,6 @@ Shall we use it as the general CPAN build and cache directory?
 
     my_yn_prompt(cache_metadata => 1, $matcher);
     my_yn_prompt(use_sqlite => 0, $matcher);
-    if ($CPAN::Config->{use_sqlite}) {
-        my_dflt_prompt(sqlite_dbname => "cpansql.db", $matcher); # 8.3
-    }
 
     #
     #= Do we follow PREREQ_PM?
@@ -1085,8 +1082,6 @@ memory consumption of CPAN.pm considereably.
 
 use_sqlite => qq{Use CPAN::SQLite if available? (yes/no)?},
 
-sqlite_dbname => qq{SQLite shall use which filename?},
-
 term_is_latin_intro => qq{
 
 The next option deals with the charset (aka character set) your
